@@ -11,7 +11,7 @@ our @ISA = qw(Exporter);
 our @EXPORT = qw(to_ascii to_latin1);
 our %EXPORT_TAGS = ( 'all' => [ @EXPORT ]);
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 our %ANSI_TO_ASCII_TRANSLITERATION = (qw(
          !
@@ -525,6 +525,7 @@ sub to_latin1($) {
             s/Mae/Masse/g;
             s/ma(?=el|ak|ig)/mass/g;
             s/\bma(?=en\w)/mass/g;
+            s/(ten)ma/$1mass/g; 
             s/((?:\b|$prefix)flo)/$1ss/g;
         }
         
@@ -552,7 +553,7 @@ sub to_latin1($) {
     s/Apero/Apro/g;
     s/Aragon/Aragn/g;
     s/\bdeco\b/dco/g;
-    s/socie/soci/g;
+    s/socie(?=\b|s)/soci/g;
     s/([aA])suncion/$1suncin/g;
     s/([aA])ttache/$1ttach/g;
     s/Balpare/Balpar/g;
